@@ -5,6 +5,7 @@ EWRITELEN=3
 ESTRTOLONG=4
 ERESPONSE=6
 EKEEPALIVE=7
+ENOCON=8
 ECONUNKNOWN=20
 ECONPROTOCOL=21
 ECONREJECT=22
@@ -13,6 +14,7 @@ ECONCREDENTIALS=24
 ECONAUTH=25
 ECONNOT=28
 ECONLENGTH=29
+ECONTIMEOUT=30
 ESUBACKUNKNOWN=40
 ESUBACKFAIL=44
 STIMEOUT=0
